@@ -103,7 +103,7 @@ onOK <- function(){
 
     ### not yet perfect, especially NULL entries are not possible
     ### for didactic reasons distinguish between usage of default.levels and other?
-    command <- paste("lhs.design(","type=",dQuote(tclvalue(typerbVariable)),
+    command <- paste("lhs.design(","type=",dquote(tclvalue(typerbVariable)),
                   ", nruns=",tclvalue(nrunVar),",nfactors=",tclvalue(nfacVar),
                   ",digits=",tclvalue(digitsVar), ",seed=",tclvalue(seedVar),
                   ",",textfactornameslist.forcommand,")") 
@@ -493,7 +493,12 @@ dquote <- function(obj){
     aus <- rep("",length(obj))
     wopt <- options("warn")[[1]]
     options(warn=-1)
-    for (i in 1:length(obj)) if (is.na(as.numeric(obj[i]))) aus[i] <- paste('"',obj[i],'"',sep="") 
+    for (i in 1:length(obj)) if (is.na(as.numeric(obj[i]))) {
+            if (length(grep('"',obj[i])>0))
+            aus[i] <- paste("'",obj[i],"'",sep="") 
+            else
+            aus[i] <- paste('"',obj[i],'"',sep="") 
+            }
           else aus[i] <- obj[i]
     options(warn=wopt)
     aus
